aboutsummaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
-rw-r--r--feed.php2
-rw-r--r--inc/changelog.php8
-rw-r--r--inc/common.php2
3 files changed, 6 insertions, 6 deletions
diff --git a/feed.php b/feed.php
index 85ddd417d..3302d854f 100644
--- a/feed.php
+++ b/feed.php
@@ -472,7 +472,7 @@ function rssRecentChanges($opt) {
$flags = 0;
if(!$conf['rss_show_deleted']) $flags += RECENTS_SKIP_DELETED;
if(!$opt['show_minor']) $flags += RECENTS_SKIP_MINORS;
- if($opt['only_new']) $flags += RECENTS_ONLY_NEW_PAGES;
+ if($opt['only_new']) $flags += RECENTS_ONLY_CREATION;
if($opt['content_type'] == 'media' && $conf['mediarevisions']) $flags += RECENTS_MEDIA_CHANGES;
if($opt['content_type'] == 'both' && $conf['mediarevisions']) $flags += RECENTS_MEDIA_PAGES_MIXED;
diff --git a/inc/common.php b/inc/common.php
index bcf0edb69..eb6b41874 100644
--- a/inc/common.php
+++ b/inc/common.php
@@ -22,7 +22,7 @@ define('RECENTS_SKIP_MINORS', 4);
define('RECENTS_SKIP_SUBSPACES', 8);
define('RECENTS_MEDIA_CHANGES', 16);
define('RECENTS_MEDIA_PAGES_MIXED', 32);
-define('RECENTS_ONLY_NEW_PAGES', 64);
+define('RECENTS_ONLY_CREATION', 64);
/**
* Wrapper around htmlspecialchars()
diff --git a/inc/changelog.php b/inc/changelog.php
index d9b1576d0..2ea673860 100644
--- a/inc/changelog.php
+++ b/inc/changelog.php
@@ -205,7 +205,7 @@ function addMediaLogEntry(
*
* RECENTS_SKIP_DELETED - don't include deleted pages
* RECENTS_SKIP_MINORS - don't include minor changes
* RECENTS_ONLY_NEW_PAGES - only include new created pages
* RECENTS_SKIP_SUBSPACES - don't include subspaces
* RECENTS_MEDIA_CHANGES - return media changes instead of page changes
* RECENTS_MEDIA_PAGES_MIXED - return both media changes and page changes
@@ -300,7 +300,7 @@ function getRecents($first,$num,$ns='',$flags=0){
*
* RECENTS_SKIP_DELETED - don't include deleted pages
* RECENTS_SKIP_MINORS - don't include minor changes
* RECENTS_ONLY_NEW_PAGES - only include new created pages
* RECENTS_SKIP_SUBSPACES - don't include subspaces
* RECENTS_MEDIA_CHANGES - return media changes instead of page changes
*
@@ -375,8 +375,8 @@ function _handleRecent($line,$ns,$flags,&$seen){
// skip seen ones
if(isset($seen[$recent['id']])) return false;
- // skip changes, of only new pages are requested
- if($recent['type']!==DOKU_CHANGE_TYPE_CREATE && ($flags & RECENTS_ONLY_NEW_PAGES)) return false;
+ // skip changes, of only new items are requested
+ if($recent['type']!==DOKU_CHANGE_TYPE_CREATE && ($flags & RECENTS_ONLY_CREATION)) return false;
// skip minors
if($recent['type']===DOKU_CHANGE_TYPE_MINOR_EDIT && ($flags & RECENTS_SKIP_MINORS)) return false;
@@ -205,7 +205,7 @@ function addMediaLogEntry(
* RECENTS_SKIP_DELETED - don't include deleted pages
* RECENTS_SKIP_MINORS - don't include minor changes
- * RECENTS_ONLY_NEW_PAGES - only include new created pages
+ * RECENTS_ONLY_CREATION - only include new created pages and media
* RECENTS_SKIP_SUBSPACES - don't include subspaces
* RECENTS_MEDIA_CHANGES - return media changes instead of page changes
@@ -300,7 +300,7 @@ function getRecents($first,$num,$ns='',$flags=0){
* RECENTS_SKIP_DELETED - don't include deleted pages
* RECENTS_SKIP_MINORS - don't include minor changes
- * RECENTS_ONLY_NEW_PAGES - only include new created pages
+ * RECENTS_ONLY_CREATION - only include new created pages and media
* RECENTS_SKIP_SUBSPACES - don't include subspaces
* RECENTS_MEDIA_CHANGES - return media changes instead of page changes